#[unsafe(no_mangle)]pub extern "C" fn htonl(hostlong: uint32_t) -> uint32_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts hostlong from host byte order to network byte order.
#[unsafe(no_mangle)]pub extern "C" fn htonl(hostlong: uint32_t) -> uint32_tSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts hostlong from host byte order to network byte order.