#[unsafe(no_mangle)]pub extern "C" fn htons(hostshort: uint16_t) -> uint16_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts hostshort from host byte order to network byte order.
#[unsafe(no_mangle)]pub extern "C" fn htons(hostshort: uint16_t) -> uint16_tSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts hostshort from host byte order to network byte order.