#[unsafe(no_mangle)]pub extern "C" fn ntohl(netlong: uint32_t) -> uint32_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts netlong from network byte order to host byte order.
#[unsafe(no_mangle)]pub extern "C" fn ntohl(netlong: uint32_t) -> uint32_tSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts netlong from network byte order to host byte order.