#[unsafe(no_mangle)]pub extern "C" fn ntohs(netshort: uint16_t) -> uint16_tExpand description
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts netshort from network byte order to host byte order.
#[unsafe(no_mangle)]pub extern "C" fn ntohs(netshort: uint16_t) -> uint16_tSee https://pubs.opengroup.org/onlinepubs/9799919799/functions/htonl.html.
Converts netshort from network byte order to host byte order.